@@ -62,7 +62,7 @@ def bin2float(n: str, e: int = None, f: int = None, ieee: bool = False):
         La représentation binaire à décoder.
     e: int
         Le nombre de bits représentant l'exposant
-        
+
     f: int
         Le nombre de bits représentant la mantisse
     ieee: bool
@@ -83,6 +83,7 @@ def bin2float(n: str, e: int = None, f: int = None, ieee: bool = False):
         f = 10
     elif precision == 32:
         # https://en.wikipedia.org/wiki/Single-precision_floating-point_format
+        e = 8
         f = 23
     elif precision == 64:
         # https://en.wikipedia.org/wiki/Double-precision_floating-point_format
@@ -93,19 +94,19 @@ def bin2float(n: str, e: int = None, f: int = None, ieee: bool = False):
     est_positif = True if n[0] == "0" else False
     décalage = 2 ** (e - 1) - 1
     exposant = int(n[1 : e + 1], 2)
-    mantisse_bin=n[e + 1 :]
-    
+    mantisse_bin = n[e + 1 :]
+
     # cas spécial ieee
     if ieee:
         # zéros
         if exposant == 0 and int(mantisse_bin, 2) == 0:
-                return 0
+            return 0
         # Nan et infinity
-        elif exposant == 2**e -1:
+        elif exposant == 2**e - 1:
             if int(mantisse_bin, 2) > 0:
-                return float('nan')
+                return float("nan")
             else:
-                return float('inf') if est_positif else -float('inf')
+                return float("inf") if est_positif else -float("inf")
     if exposant > 0:
         # nombre normalisé
         m = 1
@@ -114,9 +115,9 @@ def bin2float(n: str, e: int = None, f: int = None, ieee: bool = False):
         # nombre dénormalisé
         m = 0
         exp = exposant - décalage + 1
-    
+
     for i, bit in enumerate(mantisse_bin):
         m += int(bit) * 2 ** (-i - 1)
     # print("mantisse", m)
-    val = m * 2**exp   
+    val = m * 2**exp
     return val if est_positif else -val
